@@ -35,6 +35,7 @@ class FileConverter(TableConverter):
         is_type_inference,
         is_type_hint_header,
         verbosity_level,
+        max_workers: int,
         format_name,
         encoding,
         exclude_pattern,
@@ -42,7 +43,7 @@ class FileConverter(TableConverter):
     ):
         super().__init__(
             logger,
-            con,
+            con=con,
             symbol_replace_value=symbol_replace_value,
             add_pri_key_name=add_pri_key_name,
             convert_configs=convert_configs,
@@ -50,6 +51,7 @@ class FileConverter(TableConverter):
             is_type_inference=is_type_inference,
             is_type_hint_header=is_type_hint_header,
             verbosity_level=verbosity_level,
+            max_workers=max_workers,
             format_name=format_name,
             encoding=encoding,
         )
@@ -91,7 +93,7 @@ class FileConverter(TableConverter):
 
             for table_name in changed_table_name_set:
                 record = deepcopy(source_info_record_base)
-                record.format_name = "ipynb"
+                record.format_name = "ipynb"  # type: ignore
                 record.dst_table = table_name
                 SourceInfo.insert(record)
         else:
@@ -145,7 +147,7 @@ class FileConverter(TableConverter):
                     return
 
                 record = deepcopy(source_info_record_base)
-                record.dst_table = sqlite_tabledata.table_name
+                record.dst_table = sqlite_tabledata.table_name  # type: ignore
                 SourceInfo.insert(record)
         except ptr.OpenError as e:
             logger.error(
@@ -160,7 +162,7 @@ class FileConverter(TableConverter):
                     loader.loader, source_info_record_base
                 ):
                     record = deepcopy(source_info_record_base)
-                    record.dst_table = table_name
+                    record.dst_table = table_name  # type: ignore
                     SourceInfo.insert(record)
             else:
                 logger.error(
