@@ -5,18 +5,24 @@
 import abc
 import os.path
 import re
+from typing import Mapping  # noqa
 from typing import TYPE_CHECKING, Dict, List, Optional, Sequence, Set, Tuple
 from urllib.parse import urlparse
 
 import msgfy
 import nbformat
 import retryrequests
-import simplejson as json
 from simplesqlite import SimpleSQLite
 
 from .._common import ResultLogger
 
 
+try:
+    import ujson as json
+except ImportError:
+    import json  # type: ignore
+
+
 if TYPE_CHECKING:
     from ._base import SourceInfo  # noqa
 
@@ -189,8 +195,11 @@ class MetaDataConverter(JupyterNotebookConverterBase):
     def __convert_language_info(self) -> None:
         target = "language_info"
         language_info = self.__metadata.get(target)
-        record_list = []
 
+        if not language_info:
+            return
+
+        record_list = []
         codemirror_mode = language_info.get("codemirror_mode")
         if isinstance(codemirror_mode, dict):
             for key, value in codemirror_mode.items():
@@ -300,7 +309,7 @@ class CellConverter(JupyterNotebookConverterBase):
             )
             self._changed_table_name_set.add(table_name)
 
-    def __to_kv_records(self, data_map: Dict) -> List[Tuple]:
+    def __to_kv_records(self, data_map: Mapping) -> List[Tuple]:
         record_list = []  # type: List[Tuple]
         for key, value in data_map.items():
             if key == "metadata":
@@ -404,7 +413,9 @@ class CellConverter(JupyterNotebookConverterBase):
 
         return True
 
-    def __convert_output_data(self, output_data: Dict[str, Dict], need_create_table: bool) -> bool:
+    def __convert_output_data(
+        self, output_data: Dict[str, Mapping], need_create_table: bool
+    ) -> bool:
         output_key = "data"
         if output_key not in output_data:
             return False
