@@ -61,6 +61,7 @@ class UrlConverter(TableConverter):
         is_type_inference,
         is_type_hint_header,
         verbosity_level,
+        max_workers: int,
         format_name,
         encoding,
         proxy,
@@ -75,6 +76,7 @@ class UrlConverter(TableConverter):
             is_type_inference=is_type_inference,
             is_type_hint_header=is_type_hint_header,
             verbosity_level=verbosity_level,
+            max_workers=max_workers,
             format_name=format_name,
             encoding=encoding,
         )
@@ -98,7 +100,7 @@ class UrlConverter(TableConverter):
 
             for table_name in changed_table_name_set:
                 record = deepcopy(source_info_record_base)
-                record.format_name = "ipynb"
+                record.format_name = "ipynb"  # type: ignore
                 record.dst_table = table_name
                 record.size = nb_size
                 SourceInfo.insert(record)
@@ -135,7 +137,7 @@ class UrlConverter(TableConverter):
                     continue
 
                 record = deepcopy(source_info_record_base)
-                record.dst_table = sqlite_tabledata.table_name
+                record.dst_table = sqlite_tabledata.table_name  # type: ignore
                 SourceInfo.insert(record)
         except ptr.ValidationError as e:
             if loader.format_name == "json":
