@@ -6,8 +6,8 @@ import pytest
 from click.testing import CliRunner
 from simplesqlite import SimpleSQLite
 
+from sqlitebiter.__main__ import cmd
 from sqlitebiter._const import ExitCode
-from sqlitebiter.sqlitebiter import cmd
 
 from .common import print_traceback
 
